spoon.transports.LinkMessage

Package spoon :: Package transports :: Class LinkMessage |
[show private | hide private]
[frames | no frames]

## Type LinkMessage

    object --+
             |
            LinkMessage

Link message is the wrapper which will contain messages sent between two directly connected nodes. This message just consists of a msg type (an int) and some arbitrary attachment. The msgtype determines what system will deal with the message. Since this is strictly for use between directly connected nodes, there's no need for src or destination fields.

Method Summary
| `__init__(self, msgtype, attach)`
Inherited from object
| ``__delattr__`(...)` x.__delattr__('name') <==> del x.name
| ``__getattribute__`(...)` x.__getattribute__('name') <==> x.name
| ``__hash__`(x)` x.__hash__() <==> hash(x)
| ``__new__`(T, S, ...)` T.__new__(S, ...) -> a new object with type S, a subtype of T
| ``__reduce__`(...)` helper for pickle
| ``__reduce_ex__`(...)` helper for pickle
| ``__repr__`(x)` x.__repr__() <==> repr(x)
| ``__setattr__`(...)` x.__setattr__('name', value) <==> x.name = value
| ``__str__`(x)` x.__str__() <==> str(x)

Generated by Epydoc 2.1 on Sun Nov 26 15:32:15 2006 | http://epydoc.sf.net